@@ -124,7 +124,17 @@ class ProviderBase(
         :param region: The AWS region this resource belongs to. Default: - the resource is in the same region as the stack it belongs to
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProviderBase.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                account: typing.Optional[builtins.str] = None,
+                environment_from_arn: typing.Optional[builtins.str] = None,
+                physical_name: typing.Optional[builtins.str] = None,
+                region: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = aws_cdk.ResourceProps(
@@ -166,7 +176,22 @@ class ProviderBase(
         :param role_name: A name for the IAM role. For valid values, see the RoleName parameter for the CreateRole action in the IAM API Reference. IMPORTANT: If you specify a name, you cannot perform updates that require replacement of this resource. You can perform updates that require no or some interruption. If you must replace the resource, specify a new name. If you specify a name, you must specify the CAPABILITY_NAMED_IAM value to acknowledge your template's capabilities. For more information, see Acknowledging IAM Resources in AWS CloudFormation Templates. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the role name.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProviderBase.create_role)
+            def stub(
+                id: builtins.str,
+                repo: typing.Sequence[typing.Union[RepositoryConfig, typing.Dict[str, typing.Any]]],
+                *,
+                assumed_by: aws_cdk.aws_iam.IPrincipal,
+                description: typing.Optional[builtins.str] = None,
+                external_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
+                inline_policies: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_iam.PolicyDocument]] = None,
+                managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
+                max_session_duration: typing.Optional[aws_cdk.Duration] = None,
+                path: typing.Optional[builtins.str] = None,
+                permissions_boundary: typing.Optional[aws_cdk.aws_iam.IManagedPolicy] = None,
+                role_name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument repo", value=repo, expected_type=type_hints["repo"])
         role_props = aws_cdk.aws_iam.RoleProps(
@@ -223,7 +248,14 @@ class RepositoryConfig:
         :param filter: The sub prefix string from the JWT token used to be validated by AWS. Appended after ``repo:${owner}/${repo}:`` in an IAM role trust relationship. The default value '*' indicates all branches and all tags from this repo. Example: repo:octo-org/octo-repo:ref:refs/heads/demo-branch - only allowed from ``demo-branch`` repo:octo-org/octo-repo:ref:refs/tags/demo-tag - only allowed from ``demo-tag``. repo:octo-org/octo-repo:pull_request - only allowed from the ``pull_request`` event. repo:octo-org/octo-repo:environment:Production - only allowd from ``Production`` environment name. Default: '*'
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RepositoryConfig.__init__)
+            def stub(
+                *,
+                owner: builtins.str,
+                repo: builtins.str,
+                filter: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument owner", value=owner, expected_type=type_hints["owner"])
             check_type(argname="argument repo", value=repo, expected_type=type_hints["repo"])
             check_type(argname="argument filter", value=filter, expected_type=type_hints["filter"])
@@ -293,7 +325,9 @@ class Provider(
         :param id: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Provider.__init__)
+            def stub(scope: constructs.Construct, id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
@@ -311,7 +345,9 @@ class Provider(
         :param id: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Provider.from_account)
+            def stub(scope: constructs.Construct, id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast(ProviderBase, jsii.sinvoke(cls, "fromAccount", [scope, id]))
